pydas
=====

.. image:: https://img.shields.io/travis/midasplatform/pydas.svg
    :target: https://travis-ci.org/midasplatform/pydas
    :alt: Linux Build Status

.. image:: https://img.shields.io/appveyor/ci/jamiesnape/pydas-g6rbj.svg
    :target: https://ci.appveyor.com/project/jamiesnape/pydas-g6rbj
    :alt: Windows Build Status

.. image:: https://img.shields.io/codacy/3c93eae1ec8f43f79df514bea7993ba1.svg
    :target: https://www.codacy.com/public/jamiesnape/midasplatformpydas
    :alt: Code Quality

.. image:: https://readthedocs.org/projects/pydas/badge?version=latest
    :target: http://pydas.readthedocs.org/
    :alt: Documentation

.. image:: https://img.shields.io/pypi/v/pydas.svg
    :target: https://pypi.python.org/pypi/pydas/
    :alt: PyPI Package Version

.. image:: https://img.shields.io/pypi/dw/pydas.svg
    :target: https://pypi.python.org/pypi/pydas/
    :alt: Downloads

.. image:: https://img.shields.io/pypi/l/pydas.svg
    :target: https://pypi.python.org/pypi/pydas/
    :alt: License

Upload data to a `Midas Server`_ application with Python.

.. _`Midas Server`: http://www.midasplatform.org/
